CharsCount

Struct CharsCount 

pub struct CharsCount(/* private fields */);
Counts Unicode characters processed per iteration.

Attach to a benchmark to display throughput as char/s, Kchar/s, etc.

Implementations

Source

impl CharsCount

pub const fn new(count: u64) -> Self

Create a character counter with an explicit count.

pub fn of_str(s: &str) -> Self

Count the number of Unicode characters in a string slice.